@@ -7,7 +7,7 @@ from io import DEFAULT_BUFFER_SIZE
 from json import dump, load
 from os import makedirs, remove, rmdir, scandir
 from os.path import exists, dirname, join, basename, isdir
-from shutil import copyfile
+from shutil import copyfile, rmtree
 from sys import stdout
 from shutil import move
 from typing import Union, Optional, TextIO, Any, List
@@ -182,7 +182,7 @@ def gzip_compress(input_file: str, output_file: str) -> None:
                 writer.write(chunk)
 
 
-def remove_files(*files: str, ignore_errors: bool = False) -> None:
+def remove_files(*files: str, ignore_errors: bool = False, recursive: bool = False) -> None:
     """ Remove several files and empty directories at once.
 
     :param files: The list of files or empty directories to remove. To remove directories with files or subdirectories,
@@ -191,7 +191,10 @@ def remove_files(*files: str, ignore_errors: bool = False) -> None:
     """
     for file in files:
         if isdir(file):
-            rmdir(file)
+            if recursive:
+                rmtree(file)
+            else:
+                rmdir(file)
         elif not ignore_errors or exists(file):
             remove(file)
 
@@ -299,17 +302,18 @@ def read_file(filename: str, line_break: bool = True) -> List[str]:
         return [line[:-1] if not line_break and line[-1] == '\n' else line for line in file]
 
 
-def mkdir(path: Union[str, bytes], mode: int = 0o777, dir_fd: int = None) -> None:
-    """ Create a directory ignoring if the file already exists.
-    :param path: The path to the directory.
+def mkdirs(*paths: Union[str, bytes], mode: int = 0o777, dir_fd: int = None) -> None:
+    """ Create one or several directories ignoring the error if the file or folder already exists.
+    :param paths: The list of path to the directories.
     :param mode: The mode argument is ignored on Windows. By default, 0o777.
     :param dir_fd: If dir_fd is not None, it should be a file descriptor open to a directory,
         and path should be relative; path will then be relative to that directory.
         dir_fd may not be implemented on your platform.
         If it is unavailable, using it will raise a NotImplementedError.
     """
-    if not exists(path):
-        os.mkdir(path, mode, dir_fd=dir_fd)
+    for path in paths:
+        if not exists(path):
+            os.mkdir(path, mode, dir_fd=dir_fd)
 
 
 def move_files(dest: Union[str, bytes], *files: Union[str, bytes], force: bool = False, replace: bool = False) -> None:
@@ -321,7 +325,7 @@ def move_files(dest: Union[str, bytes], *files: Union[str, bytes], force: bool =
     :param replace: if any of the files exist, replace them.
     """
     if force:
-        mkdir(dest)
+        mkdirs(dest)
     for file in files:
         if exists(join(dest, file)) and replace:
             remove(join(dest, file))
@@ -348,18 +352,19 @@ def last_file(folder: str = '.', filter: str = None) -> str:
 
 class _Removable(object):
     """ Hidden class to include enter and exit methods for removable files. """
-    def __init__(self, *files: Union[str, bytes], ignore_errors: bool = False):
+    def __init__(self, *files: Union[str, bytes], ignore_errors: bool = False, recursive: bool = False):
         self.files = files
         self.ignore_errors = ignore_errors
+        self.recursive = recursive
 
     def __enter__(self) -> None:
         pass
 
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
-        remove_files(*self.files, ignore_errors=self.ignore_errors)
+        remove_files(*self.files, ignore_errors=self.ignore_errors, recursive=self.recursive)
 
 
-def removable_files(*files: Union[str, bytes], ignore_errors: bool = False) -> object:
+def removable_files(*files: Union[str, bytes], ignore_errors: bool = False, recursive: bool = False) -> object:
     """ This function is used with "with" python command. As following:
 
     .. code-block:: python
@@ -374,7 +379,7 @@ def removable_files(*files: Union[str, bytes], ignore_errors: bool = False) -> o
     :param ignore_errors: If True, ignore the errors, for example the file not found error.
     :return: A object with enter and exit methods.
     """
-    return _Removable(*files, ignore_errors=ignore_errors)
+    return _Removable(*files, ignore_errors=ignore_errors, recursive=recursive)
 
 
 def output_file_path(folder: str = '.', suffix: str = '', timestamp: bool = True, **kwargs) -> str:
@@ -386,8 +391,13 @@ def output_file_path(folder: str = '.', suffix: str = '', timestamp: bool = True
       the name. If it is a bool value and it is True, then the name of the argument is add to the file name.
     :return: The full path to the file to create.
     """
-    name = [(name if value else '') if isinstance(value, bool) else str(value) for name, value in kwargs.items()]
+    name = []
     if timestamp:
-        name.insert(0, datetime.now().strftime('%Y%m%d-%H%M%S'))
+        name.append(datetime.now().strftime('%Y%m%d-%H%M%S'))
+    for param, value in kwargs.items():
+        if isinstance(value, bool):
+            name += [param] if value else []
+        elif value:
+            name.append(str(value))
 
-    return join(folder, f'{"-".join([part for part in name if part])}{suffix}')
+    return join(folder, f'{"-".join(name)}{suffix}')
